==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidTerminalAllResBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取当前有效终端信息
 * @author: 777771
 * @date: 2021-58-04 22:58:50
 */
public class TerminalGetValidTerminalAllResBean {

        /**
         * 终端编码
         */
        private String terminalCode;

        /**
         * 终端名称
         */
        private String terminalName;

        /**
         * 终端渠道编码
         */
        private String channelCode;

        /**
         * 终端渠道名称
         */
        private String channelName;

        /**
         * 终端类型编码
         */
        private String terminalTypeCode;

        /**
         * 终端类型名称
         */
        private String terminalTypeName;

        /**
         * 门店经度
         */
        private String longitude;

        /**
         * 门店纬度
         */
        private String latitude;

    public TerminalGetValidTerminalAllResBean(){
    }

    public TerminalGetValidTerminalAllResBean(String terminalCode,String terminalName,String channelCode,String channelName,String terminalTypeCode,String terminalTypeName,String longitude,String latitude){
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
        this.channelCode=channelCode;
        this.channelName=channelName;
        this.terminalTypeCode=terminalTypeCode;
        this.terminalTypeName=terminalTypeName;
        this.longitude=longitude;
        this.latitude=latitude;
    }

    private String getTerminalCode() {
        return terminalCode;
    }

    private void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    private String getTerminalName() {
        return terminalName;
    }

    private void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
    private String getChannelCode() {
        return channelCode;
    }

    private void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }
    private String getChannelName() {
        return channelName;
    }

    private void setChannelName(String channelName) {
        this.channelName = channelName;
    }
    private String getTerminalTypeCode() {
        return terminalTypeCode;
    }

    private void setTerminalTypeCode(String terminalTypeCode) {
        this.terminalTypeCode = terminalTypeCode;
    }
    private String getTerminalTypeName() {
        return terminalTypeName;
    }

    private void setTerminalTypeName(String terminalTypeName) {
        this.terminalTypeName = terminalTypeName;
    }
    private String getLongitude() {
        return longitude;
    }

    private void setLongitude(String longitude) {
        this.longitude = longitude;
    }
    private String getLatitude() {
        return latitude;
    }

    private void setLatitude(String latitude) {
        this.latitude = latitude;
    }
}

==> biostime-openapi-sdk-1.5.8.6-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidTerminalAllResBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取当前有效终端信息
 * @author: 13258
 * @date: 2021-46-10 13:46:41
 */
public class TerminalGetValidTerminalAllResBean {

        /**
         * 终端编码
         */
        private String terminalCode;

        /**
         * 终端名称
         */
        private String terminalName;

        /**
         * 终端渠道编码
         */
        private String channelCode;

        /**
         * 终端渠道名称
         */
        private String channelName;

        /**
         * 终端类型编码
         */
        private String terminalTypeCode;

        /**
         * 终端类型名称
         */
        private String terminalTypeName;

        /**
         * 门店经度
         */
        private String longitude;

        /**
         * 门店纬度
         */
        private String latitude;

    public TerminalGetValidTerminalAllResBean(){
    }

    public TerminalGetValidTerminalAllResBean(String terminalCode,String terminalName,String channelCode,String channelName,String terminalTypeCode,String terminalTypeName,String longitude,String latitude){
        this.terminalCode=terminalCode;
        this.terminalName=terminalName;
        this.channelCode=channelCode;
        this.channelName=channelName;
        this.terminalTypeCode=terminalTypeCode;
        this.terminalTypeName=terminalTypeName;
        this.longitude=longitude;
        this.latitude=latitude;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }
    public String getTerminalName() {
        return terminalName;
    }

    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }
    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }
    public String getTerminalTypeCode() {
        return terminalTypeCode;
    }

    public void setTerminalTypeCode(String terminalTypeCode) {
        this.terminalTypeCode = terminalTypeCode;
    }
    public String getTerminalTypeName() {
        return terminalTypeName;
    }

    public void setTerminalTypeName(String terminalTypeName) {
        this.terminalTypeName = terminalTypeName;
    }
    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }
    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }
}
